@@ -7,9 +7,8 @@
 #  Authors: Revva Konstantin <k.revva@abm-jsc.ru>
 
 
-from detector_connector import DetectorConnector
+from detector_connector import DetectorConnector, DetectorAnalyzeResult
 
-from obstruction_detector_connector.obstruction_analyze_result import ObstructionAnalyzeResult
 from obstruction_detector_connector.obstruction_settings import ObstructionSettings
 
 
@@ -20,5 +19,5 @@ class ObstructionDetectorConnector(DetectorConnector):
     def __init__(self, config: Config, context: Context):
         super().__init__(config=config,
                          context=context,
-                         detector_analyze_result_type=ObstructionAnalyzeResult,
+                         detector_analyze_result_type=DetectorAnalyzeResult,
                          detector_settings_type=ObstructionSettings)
